@@ -22,8 +22,8 @@ tox_chemicals <- tox_chemicals
 
 chem_info_with_names <- chem_info %>%
   left_join(select(tox_chemicals,
-                   CAS = Substance_CASRN,
-                   Chemical = Substance_Name),
+                   CAS = casn,
+                   Chemical = chnm),
             by = "CAS")
 
 head(chem_info_with_names)
